@@ -1,7 +1,7 @@
 ;;;
 ;;; gauche.test.script - test-script
 ;;;
-;;;   Copyright (c) 2017-2020  Shiro Kawai  <shiro@acm.org>
+;;;   Copyright (c) 2017-2021  Shiro Kawai  <shiro@acm.org>
 ;;;
 ;;;   Redistribution and use in source and binary forms, with or without
 ;;;   modification, are permitted provided that the following conditions
@@ -35,17 +35,17 @@
 ;; depending on other modules.
 (select-module gauche.test)
 (use file.util)
-(use srfi-1)
+(use scheme.list)
 (use srfi-13)
 
 ;; Check toplevel bindings of a script file.  Script files can have their
 ;; own modules, but they usually don't have.  For this test, we load the
 ;; script file into an anonymous module then use test-module on it if it
 ;; doesn't have its own module.
-(define (test-script file :key (allow-undefined '()) 
+(define (test-script file :key (allow-undefined '())
                                (bypass-arity-check '())
                                (compile-only #f))
-  (define file-abs-path 
+  (define file-abs-path
     (if (relative-path? file)
       (simplify-path (build-path (current-directory) file))
       file))
