@@ -1,7 +1,7 @@
 ;;;
 ;;; csv.scm - read and write CSV (actually, xSV) format.
 ;;;
-;;;   Copyright (c) 2000-2019  Shiro Kawai  <shiro@acm.org>
+;;;   Copyright (c) 2000-2021  Shiro Kawai  <shiro@acm.org>
 ;;;
 ;;;   Redistribution and use in source and binary forms, with or without
 ;;;   modification, are permitted provided that the following conditions
@@ -32,10 +32,10 @@
 ;;;
 
 (define-module text.csv
-  (use srfi-1)
+  (use scheme.list)
+  (use scheme.charset)
   (use srfi-11)
   (use srfi-13)
-  (use srfi-14)
   (use srfi-42)
   (use gauche.sequence)
   (export make-csv-reader
@@ -180,7 +180,7 @@
 
 ;; API
 ;; Create a procedure that converts one input row into a list of slot
-;; values, orderd in the same way as header-slots. 
+;; values, orderd in the same way as header-slots.
 ;; The permuter is the vector returned by make-csv-header-parser.
 ;; Required-slots determines if the input row is valid or not.  If
 ;; not, #f is returned.
@@ -234,4 +234,3 @@
                         [allow-gap? (record-loop (cdr rows) r)]
                         [else (reverse r)])))]
           [else (header-loop (cdr rows))])))
-
